mwifiex: rename function mwifiex_is_ba_stream_avail

The old function name sounds like checking for existing BA
stream. The function actually checks if we have room for
creating new BA stream or not.

Signed-off-by: Bing Zhao <bzhao@marvell.com>
Signed-off-by: John W. Linville <linville@tuxdriver.com>
diff --git a/drivers/net/wireless/mwifiex/11n.h b/drivers/net/wireless/mwifiex/11n.h
index 9128d2c..02602ff 100644
--- a/drivers/net/wireless/mwifiex/11n.h
+++ b/drivers/net/wireless/mwifiex/11n.h
@@ -92,9 +92,10 @@
 }
 
 /*
  * This function checks whether a BA stream is available or not.
  */
-static inline u8 mwifiex_is_ba_stream_avail(struct mwifiex_adapter *adapter)
+static inline u8 mwifiex_space_avail_for_new_ba_stream(
+					struct mwifiex_adapter *adapter)
 {
 	struct mwifiex_private *priv;
 	u8 i;
@@ -92,9 +92,10 @@
 
 /*
- * This function checks whether a BA stream is available or not.
+ * This function checks whether a space is available for new BA stream or not.
  */